@@ -24,19 +24,30 @@ def api_failed():
 # 返回自定义异常
 @api.route('/exc', methods=[METHODTYPE.GET])
 def api_exception():
-    current_app.logger.error(f'{request.method} api.exc')
+    current_app.logger.info(f'{request.method} api.exc')
     data = request.args
     if data.get('exc_flag'):
         raise AIException('内部异常', 1005)
+
     return APIResponse.success(data)
 
 
 # 使用abort抛出http异常
 @api.route('/exc2', methods=[METHODTYPE.GET])
 def api_exception2():
-    current_app.logger.error(f'{request.method} api.exc2')
+    current_app.logger.info(f'{request.method} api.exc2至本公告')
     print('after')
     data = request.args
     if data.get('exc_flag'):
         abort(400)
     return APIResponse.success(data)
+
+
+# 模拟程序出错
+@api.route('/exc3', methods=[METHODTYPE.GET])
+def api_exception3():
+    current_app.logger.info(f'{request.method} api.exc3')
+    # 该句会产生异常
+    print(current_app[0])
+    data = request.args
+    return APIResponse.success(data)
