@@ -4,8 +4,8 @@ import argparse
 
 def parse_args():
     parser = argparse.ArgumentParser()
-    parser.add_argument("cmd", help="run app command!")
     parser.add_argument("-p", "--port", help="bind port!", type=int)
+    parser.add_argument("-e", "--env", help="config env param!", type=str)
     return parser.parse_args()
 
 
