@@ -5,10 +5,10 @@ gevent.monkey.patch_all()
 import multiprocessing
 
 # debug = True
-bind = "0.0.0.0:8000"
-pidfile = "logs/gunicorn.pid"
-# accesslog = "logs/gaccess.log"
-# errorlog = "logs/gdebug.log"
+bind = "0.0.0.0:8080"
+pidfile = "gunicorn.pid"
+# accesslog = "log/gaccess.log"
+# errorlog = "log/gdebug.log"
 loglevel = 'INFO'
 capture_output = True
 daemon = True
